@@ -19,4 +19,4 @@ ktau = function(truth, response, ...) {
 }
 
 #' @include measures.R
-add_measure(ktau, "regr", -1, 1, FALSE)
+add_measure(ktau, "Kendall's tau", "regr", -1, 1, FALSE)
